@@ -359,6 +359,12 @@ class Registry(Mapping[URI, Resource[D]]):
         value = registry._anchors.get((uri, name))
         if value is not None:
             return Retrieved(value=value, registry=registry)
+        if "/" in name:
+            raise exceptions.InvalidAnchor(
+                ref=uri,
+                resource=self[uri],
+                anchor=name,
+            )
         raise exceptions.NoSuchAnchor(ref=uri, resource=self[uri], anchor=name)
 
     def contents(self, uri: URI) -> D:
