@@ -91,7 +91,14 @@ class PointerToNowhere(Unresolvable):
     resource: Resource[Any]
 
     def __str__(self):
-        return f"{self.ref!r} does not exist within {self.resource.contents!r}"
+        msg = f"{self.ref!r} does not exist within {self.resource.contents!r}"
+        if self.ref == "/":
+            msg += (
+                ". The pointer '/' is a valid JSON Pointer but it points to "
+                "an empty string property ''. If you intended to point "
+                "to the entire resource, you should use '#'."
+            )
+        return msg
 
 
 @frozen
@@ -107,3 +114,23 @@ class NoSuchAnchor(Unresolvable):
         return (
             f"{self.anchor!r} does not exist within {self.resource.contents!r}"
         )
+
+
+@frozen
+class InvalidAnchor(Unresolvable):
+    """
+    An anchor which could never exist in a resource was dereferenced.
+
+    It is somehow syntactically invalid.
+    """
+
+    resource: Resource[Any]
+    anchor: str
+
+    def __str__(self):
+        return (
+            f"'#{self.anchor}' is not a valid anchor, neither as a "
+            "plain name anchor nor as a JSON Pointer. You may have intended "
+            f"to use '#/{self.anchor}', as the slash is required *before each "
+            "segment* of a JSON pointer."
+        )
